CREATE TABLE kiwi_profile (
profile_id int(10) NOT NULL PRIMARY KEY,
profile_name varchar(250),
profile_project char(5),
profile_schedule char(5),
profile_approval char(5),
profile_file char(5),
profile_forum char(5),
profile_mockup char(5),
profile_support char(5),
profile_user char(5),
profile_system char(5),
profile_admin char(5),
profile_event char(5)
) TYPE=InnoDB;

INSERT INTO kiwi_profile VALUES('500','Administrator','RECDA','RECDA','RECDA','RECDA','RECD','RECDA','RECDA','RECDA','R','R','RECDA');
INSERT INTO kiwi_profile VALUES('400','Manager','RECD','RECDA','RECDA','RECDA','RECD','RECDA','RECDA','','','R','RECD');
INSERT INTO kiwi_profile VALUES('300','Employee','R','R','REC','REC','REC','RECD','REC','','','R','R');
INSERT INTO kiwi_profile VALUES('200','Contractor','R','R','REC','REC','REC','R','RC','','','R','');
INSERT INTO kiwi_profile VALUES('100','Client','R','R','REC','REC','','R','RC','','','R','');

CREATE TABLE kiwi_organization (
organization_id int(10) NOT NULL PRIMARY KEY,
organization_name varchar(250),
organization_pn varchar(250),
organization_fn varchar(250),
organization_url varchar(250),
organization_address text,
organization_comments text,
organization_created bigint(20),
organization_modified bigint(20)
) TYPE=InnoDB;

CREATE TABLE kiwi_user (
user_id int(10) NOT NULL PRIMARY KEY,
profile_id int(10) NOT NULL,
organization_id int(10),
user_name varchar(250),
user_title varchar(250),
user_email varchar(250) UNIQUE,
user_wp varchar(250),
user_hp varchar(250),
user_mp varchar(250),
user_fax varchar(250),
user_address text,
user_comments text,
user_username varchar(150) NOT NULL UNIQUE,
user_password varchar(150) NOT NULL,
user_created bigint(20),
user_modified bigint(20),
user_notify varchar(50),
user_attempt int(10),
user_blocked bigint(20),
user_key char(40),
user_active char(1),
user_timezone decimal(10,2)
) TYPE=InnoDB;

CREATE TABLE kiwi_project (
project_id int(10) NOT NULL PRIMARY KEY,
organization_id int(10),
project_status varchar(100),
project_name varchar(250),
project_priority varchar(250),
project_description text,
project_development_url varchar(250),
project_finalsite_url varchar(250),
project_created bigint(20),
project_modified bigint(20),
project_poster_id int(10),
KEY (project_poster_id),
FOREIGN KEY (project_poster_id) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_file (
file_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
user_id int(10) NOT NULL,
file_path varchar(250),
file_type varchar(250),
file_parent int(10),
file_status varchar(250),
file_comments text,
file_version varchar(250),
file_created bigint(20),
file_modified bigint(20),
file_published varchar(10),
KEY (project_id),
KEY (user_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_schedule (
schedule_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
schedule_group_id int(10),
schedule_name varchar(150),
schedule_comments text,
schedule_status int(10),
schedule_priority varchar(150),
schedule_start bigint(20),
schedule_duration int(10),
schedule_delay int(10),
schedule_budget_cost decimal(50,2),
schedule_budget_hour decimal(50,2),
schedule_created bigint(20),
schedule_modified bigint(20),
schedule_end bigint(20),
schedule_poster_id int(10),
KEY (project_id),
KEY (schedule_poster_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (schedule_poster_id) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_schedule_relation (
schedule_relation_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
schedule_relation_parent int(10) NOT NULL,
schedule_relation_child int(10) NOT NULL,
schedule_relation_type varchar(150),
schedule_relation_lead int(10),
KEY (project_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
KEY (schedule_relation_parent),
FOREIGN KEY (schedule_relation_parent) REFERENCES kiwi_schedule(schedule_id),
KEY (schedule_relation_child),
FOREIGN KEY (schedule_relation_child) REFERENCES kiwi_schedule(schedule_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_schedule_group (
schedule_group_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
schedule_group_name varchar(150),
schedule_group_created bigint(20),
schedule_group_modified bigint(20),
KEY (project_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_user_schedule (
user_schedule_id int(10) NOT NULL PRIMARY KEY,
user_id int(10) NOT NULL,
project_id int(10) NOT NULL,
schedule_id int(10) NOT NULL,
user_schedule_created bigint(20),
KEY (user_id),
KEY (project_id),
KEY (schedule_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (schedule_id) REFERENCES kiwi_schedule(schedule_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_approval (
approval_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
approval_requested_by int(10) NOT NULL,
approval_requested_from int(10) NOT NULL,
approval_name varchar(250),
approval_comments text,
approval_created bigint(20),
approval_modified bigint(20),
KEY (project_id),
KEY (approval_requested_by),
KEY (approval_requested_from),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (approval_requested_by) REFERENCES kiwi_user(user_id),
FOREIGN KEY (approval_requested_from) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_approval_file (
approval_file_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
approval_id int(10) NOT NULL,
file_id int(10) NOT NULL,
approval_file_status varchar(250),
approval_file_created bigint(20),
approval_file_modified bigint(20),
KEY (project_id),
KEY (approval_id),
KEY (file_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (approval_id) REFERENCES kiwi_approval(approval_id),
FOREIGN KEY (file_id) REFERENCES kiwi_file(file_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_approval_log (
approval_log_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
user_id int(10),
approval_id int(10) NOT NULL,
approval_log_comments text,
approval_log_created bigint(20),
KEY (project_id),
KEY (user_id),
KEY (approval_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id),
FOREIGN KEY (approval_id) REFERENCES kiwi_approval(approval_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_expense (
expense_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
schedule_id int(10) NOT NULL,
expense_name varchar(250),
expense_amount decimal(50,2),
expense_comments text,
expense_created bigint(20),
expense_modified bigint(20),
KEY (project_id),
KEY (schedule_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (schedule_id) REFERENCES kiwi_schedule(schedule_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_forum_topic (
forum_topic_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
forum_topic_poster_id int(10) NOT NULL,
forum_topic_title text,
forum_topic_views integer,
forum_topic_messages integer,
forum_topic_created bigint(20),
forum_topic_modified bigint(20),
forum_topic_locked char(1),
forum_topic_sticky char(1),
forum_topic_deleted char(1),
KEY (project_id),
KEY (forum_topic_poster_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (forum_topic_poster_id) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_forum_message (
forum_message_id int(10) NOT NULL PRIMARY KEY,
forum_topic_id int(10) NOT NULL,
user_id int(10) NOT NULL,
forum_message_comments text,
forum_message_created bigint(20),
forum_message_modified bigint(20),
KEY (forum_topic_id),
KEY (user_id),
FOREIGN KEY (forum_topic_id) REFERENCES kiwi_forum_topic(forum_topic_id) ON DELETE CASCADE,
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_forum_attachment (
forum_attachment_id int(10) NOT NULL PRIMARY KEY,
forum_message_id int(10) NOT NULL,
project_id int(10) NOT NULL,
file_id int(10) NOT NULL,
KEY (forum_message_id),
KEY (project_id),
KEY (file_id),
FOREIGN KEY (forum_message_id) REFERENCES kiwi_forum_message(forum_message_id) ON DELETE CASCADE,
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (file_id) REFERENCES kiwi_file(file_id) ON DELETE CASCADE
) TYPE=InnoDB;

CREATE TABLE kiwi_log (
log_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
schedule_id int(10) NOT NULL,
user_id int(10) NOT NULL,
log_rate decimal(50,2),
log_hours decimal(50,2),
log_comments text,
log_created bigint(20),
KEY (project_id),
KEY (schedule_id),
KEY (user_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (schedule_id) REFERENCES kiwi_schedule(schedule_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_mockup (
mockup_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
user_id int(10) NOT NULL,
file_id int(10),
mockup_parent int(10),
mockup_name varchar(250),
mockup_comments text,
mockup_created bigint(20),
mockup_modified bigint(20),
KEY (project_id),
KEY (user_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_project_user (
project_user_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
user_id int(10) NOT NULL,
project_user_created bigint(20),
project_user_status varchar(150),
KEY (project_id),
KEY (user_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_review (
review_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
user_id int(10) NOT NULL,
file_id int(10) NOT NULL,
review_comments text,
review_created int(10),
KEY (project_id),
KEY (user_id),
KEY (file_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id),
FOREIGN KEY (file_id) REFERENCES kiwi_file(file_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_support_topic (
support_topic_id int(10) NOT NULL PRIMARY KEY,
project_id int(10) NOT NULL,
support_topic_poster_id int(10) NOT NULL,
support_topic_operator_id int(10),
support_topic_title text,
support_topic_views integer,
support_topic_messages integer,
support_topic_created bigint(20),
support_topic_modified bigint(20),
support_topic_priority varchar(150),
support_topic_status varchar(150),
KEY (project_id),
KEY (support_topic_poster_id),
KEY (support_topic_operator_id),
FOREIGN KEY (project_id) REFERENCES kiwi_project(project_id),
FOREIGN KEY (support_topic_poster_id) REFERENCES kiwi_user(user_id),
FOREIGN KEY (support_topic_operator_id) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_support_message (
support_message_id int(10) NOT NULL PRIMARY KEY,
support_topic_id int(10) NOT NULL,
user_id int(10) NOT NULL,
support_message_comments text,
support_message_created bigint(20),
support_message_modified bigint(20),
KEY (support_topic_id),
KEY (user_id),
FOREIGN KEY (support_topic_id) REFERENCES kiwi_support_topic(support_topic_id) ON DELETE CASCADE,
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_user_log (
user_log_id int(10) NOT NULL PRIMARY KEY,
user_username varchar(150),
user_password varchar(150),
user_log_ip varchar(150),
user_log_session varchar(150),
user_log_status varchar(150),
user_log_date bigint(20),
user_log_connected varchar(150)
) TYPE=InnoDB;

CREATE TABLE kiwi_holiday (
holiday_id int(10) NOT NULL PRIMARY KEY,
holiday_name varchar(250),
holiday_date bigint(20),
holiday_created bigint(20)
) TYPE=InnoDB;

CREATE TABLE kiwi_history (
history_id bigint(20) NOT NULL PRIMARY KEY,
user_id int(10) NOT NULL,
history_location text,
history_url text,
history_created bigint(20),
KEY (user_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_note (
note_id bigint(20) NOT NULL PRIMARY KEY,
user_id int(10) NOT NULL,
note_comments text,
note_type  varchar(50),
note_created bigint(20),
note_modified bigint(20),
KEY (user_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_event (
event_id int(10) NOT NULL PRIMARY KEY,
user_id int(10) NOT NULL,
event_title text,
event_location text,
event_comments text,
event_start bigint(20),
event_end bigint(20),
event_timezone decimal(10,2),
event_type varchar(25),
event_created bigint(20),
event_modified bigint(20),
KEY (user_id),
FOREIGN KEY (user_id) REFERENCES kiwi_user(user_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_event_recursion (
event_recursion_id int(10) NOT NULL PRIMARY KEY,
event_id int(10) NOT NULL,
event_recursion_frequency varchar(50),
event_recursion_interval int(10),
event_recursion_bymonth int(10),
event_recursion_bymonthday int(10),
event_recursion_byday varchar(50),
event_recursion_byyearday int(10),
event_recursion_byweekno int(10),
event_recursion_bysetpos int(10),
event_recursion_until bigint(20),
KEY (event_id),
FOREIGN KEY (event_id) REFERENCES kiwi_event(event_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_event_exception (
event_exception_id int(10) NOT NULL PRIMARY KEY,
event_id int(10) NOT NULL,
event_parent int(10) NOT NULL,
event_exception_date bigint(20),
KEY (event_id),
KEY (event_parent),
FOREIGN KEY (event_id) REFERENCES kiwi_event(event_id),
FOREIGN KEY (event_parent) REFERENCES kiwi_event(event_id)
) TYPE=InnoDB;

CREATE TABLE kiwi_session (
session_id varchar(250) NOT NULL PRIMARY KEY,
session_data text,
session_expires bigint(20)
) TYPE=InnoDB;

CREATE TABLE kiwi_notification (
notification_id int(10) NOT NULL PRIMARY KEY,
notification_module varchar(50),
notification_action varchar(50),
notification_status varchar(50)
) TYPE=InnoDB;

INSERT INTO kiwi_notification VALUES(1,'schedule','create','Y');
INSERT INTO kiwi_notification VALUES(2,'schedule','edit','N');
INSERT INTO kiwi_notification VALUES(3,'schedule','status','N');
INSERT INTO kiwi_notification VALUES(4,'approval','create','Y');
INSERT INTO kiwi_notification VALUES(5,'approval','status','Y');
INSERT INTO kiwi_notification VALUES(6,'approval','comment','Y');
INSERT INTO kiwi_notification VALUES(7,'file','upload','Y');
INSERT INTO kiwi_notification VALUES(8,'file','update','Y');
INSERT INTO kiwi_notification VALUES(9,'file','review','Y');
INSERT INTO kiwi_notification VALUES(10,'forum','post','Y');
INSERT INTO kiwi_notification VALUES(11,'forum','reply','Y');
INSERT INTO kiwi_notification VALUES(12,'mockup','create','N');
INSERT INTO kiwi_notification VALUES(13,'mockup','edit','N');
INSERT INTO kiwi_notification VALUES(14,'support','post','Y');
INSERT INTO kiwi_notification VALUES(15,'support','reply','Y');

CREATE TABLE event_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE event_recursion_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE event_exception_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;

CREATE TABLE note_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE organization_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE user_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE project_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE file_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE schedule_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE schedule_relation_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE schedule_group_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE approval_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE approval_file_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE approval_log_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE expense_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE forum_attachment_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE log_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE mockup_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE project_user_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE user_schedule_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE review_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE support_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE user_log_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE holiday_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE history_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE profile_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;

CREATE TABLE forum_topic_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE forum_message_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;

CREATE TABLE support_topic_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;
CREATE TABLE support_message_id_seq (id int(10) unsigned NOT NULL PRIMARY KEY auto_increment) TYPE=InnoDB;

INSERT INTO profile_id_seq VALUES('1000');

INSERT INTO forum_topic_id_seq VALUES('100000');
INSERT INTO forum_message_id_seq VALUES('100000');

INSERT INTO support_topic_id_seq VALUES('100000');
INSERT INTO support_message_id_seq VALUES('100000');

INSERT INTO kiwi_user(user_id,profile_id,user_name,user_username,user_password,user_active,user_timezone) VALUES ('398571525','500','Admin','admin','6441a0e520f56a5fc6f80f33b8e1f3ad6a0b75d6','Y','0');